==> haskell-bower-json-1.1.0.0-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-E5i8SRp4h3U3JMs702vk7M
key:                  bower-json-1.1.0.0-E5i8SRp4h3U3JMs702vk7M
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  63522a9585ff05d4de9465c25ae8d35f
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-E5i8SRp4h3U3JMs702vk7M
depends:
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB
    aeson-better-errors-0.9.1.3-E8GlKcd9uAg242ZfEZ4VTk base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.1.0.0-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-GsucJi6JBOu8bmcDj97R9c
key:                  bower-json-1.1.0.0-GsucJi6JBOu8bmcDj97R9c
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  ebf0ceb5b3c02332480815964ea7b973
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-GsucJi6JBOu8bmcDj97R9c
depends:
    aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5
    aeson-better-errors-0.9.1.3-FPrfg1yENINJY7NlZ13EBw base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.7.0-Kb5Gqy0LO2R6GqxRC9SGn9 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx
    vector-0.13.2.0-BWMo7dqC00725tIPRLs4rJ

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
